# -*- coding: utf-8 -*-
from ....Methods.Import import ImportError


class XlsFileError(ImportError):
    """Raised when the file_path is wrong"""

    pass
